@@ -5,16 +5,17 @@
 # Distributed under the terms of the Modified BSD License.
 
 import json
-import os.path as osp
+from pathlib import Path
+
+# import version first: https://github.com/pypa/setuptools/issues/1724#issuecomment-627241822
+from ._version import __version__, version_info
 
 from .jupyterfrontend import JupyterFrontEnd
 from .widgets import Panel, SplitPanel
 
-from ._version import __version__, version_info
+HERE = Path(__file__).parent.resolve()
 
-HERE = osp.abspath(osp.dirname(__file__))
-
-with open(osp.join(HERE, "labextension", "package.json")) as fid:
+with open(str(HERE / "labextension" / "package.json")) as fid:
     data = json.load(fid)
 
 
